# -*- coding: utf-8 -*-

# This file is part of the Ingram Micro Cloud Blue Connect connect-cli.
# Copyright (c) 2019-2020 Ingram Micro. All Rights Reserved.

DEFAULT_ENDPOINT = 'https://api.connect.cloudblue.com/public/v1'
DEFAULT_USER_AGENT = 'CloudBlue Connect CLI/'

REPORT_PARAM_TYPES = [
    'date_range',
    'date',
    'product',
    'marketplace',
    'hub',
    'checkbox',
    'choice',
    'single_line',
    'object',
]
